# numerous SDK

![pipeline](https://gitlab.com/numerous/numerous.sdk/badges/main/pipeline.svg)
![coverage](https://gitlab.com/numerous/numerous.sdk/badges/main/coverage.svg?job=pytest)

Welcome to the repository for the numerous SDK!

## Documentation

Documentation for the numerous SDK can be found at
[readthedocs.io](numeroussdk.readthedocs.io). This will be both an autogenerated
API reference, and a collection of useful guides.

## Contributing

We welcome contributions, but please read [CONTRIBUTING.md](CONTRIBUTING.md)
before you start. It lays down the processes and expectations of contributions
to the numerous SDK.

## License

The numerous SDK is licensed under the MIT License, and it can be read in
[LICENSE.md](LICENSE.txt).
